==> eanalytics-0.0.3.tar.gz: lib/src/utils/systemInfo.dart <==
import 'dart:io';

import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'package:advertising_id/advertising_id.dart'
    if (dart.library.js) 'package:eanalytics/src/utils/stubs/advertising_id.dart';

enum SystemInfoKey { OS, MODEL, UUID, BUNDLE_ID, APP_NAME, APP_VERSION, AD_ID }

Future<Map<SystemInfoKey, dynamic>> getSystemInfo() async {
  if (!kIsWeb && !Platform.isAndroid && !Platform.isIOS)
    throw PlatformException(code: 'Unsupported platform');
  var systemInfo = <SystemInfoKey, dynamic>{};

  systemInfo.addAll(parsePackageInfo(await PackageInfo.fromPlatform()));

  final device = DeviceInfoPlugin();

  if (!kIsWeb && Platform.isAndroid)
    systemInfo.addAll(parseAndroidInfo(await device.androidInfo));

  if (!kIsWeb && Platform.isIOS)
    systemInfo.addAll(parseIosInfo(await device.iosInfo));

  if (kIsWeb) systemInfo.addAll(parseWebInfo(await device.webBrowserInfo));

  systemInfo[SystemInfoKey.AD_ID] = await getAdvertiserId(false);

  return systemInfo;
}

Map<SystemInfoKey, String?> parseAndroidInfo(AndroidDeviceInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.OS:
        'Android OS ${info.version.release} (SDK ${info.version.sdkInt})',
    SystemInfoKey.MODEL: '${info.manufacturer} ${info.model}',
    SystemInfoKey.UUID: info.androidId
  };
}

Map<SystemInfoKey, String?> parseIosInfo(IosDeviceInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.OS: '${info.systemName} ${info.systemVersion}',
    SystemInfoKey.MODEL: '${info.name} ${info.model}',
    SystemInfoKey.UUID: info.identifierForVendor
  };
}

Map<SystemInfoKey, String?> parseWebInfo(WebBrowserInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.OS: '${info.platform}',
    SystemInfoKey.MODEL: '${describeEnum(info.browserName)}'
  };
}

Map<SystemInfoKey, String?> parsePackageInfo(PackageInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.BUNDLE_ID: info.packageName,
    SystemInfoKey.APP_NAME: info.appName,
    SystemInfoKey.APP_VERSION: info.version
  };
}

Future<String?> getAdvertiserId(bool requestTrackingAuthorization) async {
  try {
    if (kIsWeb)
      throw PlatformException(
          code: "advertiserId not supported on web platform");
    return await AdvertisingId.id(requestTrackingAuthorization);
  } on PlatformException {
    return null;
  }
}

==> eanalytics-0.0.5.tar.gz: lib/src/utils/systemInfo.dart <==
import 'dart:io';

import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'package:advertising_id/advertising_id.dart'
    if (dart.library.js) 'package:eanalytics/src/utils/stubs/advertising_id.dart';

enum SystemInfoKey {
  OS,
  MODEL,
  UUID,
  BUNDLE_ID,
  APP_NAME,
  APP_VERSION,
  AD_ID,
  IOS_IDFV
}

Future<Map<SystemInfoKey, dynamic>> getSystemInfo() async {
  if (!kIsWeb && !Platform.isAndroid && !Platform.isIOS)
    throw PlatformException(code: 'Unsupported platform');
  var systemInfo = <SystemInfoKey, dynamic>{};

  systemInfo.addAll(parsePackageInfo(await PackageInfo.fromPlatform()));

  final device = DeviceInfoPlugin();

  if (!kIsWeb && Platform.isAndroid)
    systemInfo.addAll(parseAndroidInfo(await device.androidInfo));

  if (!kIsWeb && Platform.isIOS)
    systemInfo.addAll(parseIosInfo(await device.iosInfo));

  if (kIsWeb) systemInfo.addAll(parseWebInfo(await device.webBrowserInfo));

  systemInfo[SystemInfoKey.AD_ID] = await getAdvertiserId(false);

  return systemInfo;
}

Map<SystemInfoKey, String?> parseAndroidInfo(AndroidDeviceInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.OS:
        'Android OS ${info.version.release} (SDK ${info.version.sdkInt})',
    SystemInfoKey.MODEL: '${info.manufacturer} ${info.model}',
    SystemInfoKey.UUID: info.androidId
  };
}

Map<SystemInfoKey, String?> parseIosInfo(IosDeviceInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.OS: '${info.systemName} ${info.systemVersion}',
    SystemInfoKey.MODEL: '${info.name} ${info.model}',
    SystemInfoKey.UUID: info.identifierForVendor,
    SystemInfoKey.IOS_IDFV: info.identifierForVendor
  };
}

Map<SystemInfoKey, String?> parseWebInfo(WebBrowserInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.OS: '${info.platform}',
    SystemInfoKey.MODEL: '${describeEnum(info.browserName)}'
  };
}

Map<SystemInfoKey, String?> parsePackageInfo(PackageInfo info) {
  return <SystemInfoKey, String?>{
    SystemInfoKey.BUNDLE_ID: info.packageName,
    SystemInfoKey.APP_NAME: info.appName,
    SystemInfoKey.APP_VERSION: info.version
  };
}

Future<String?> getAdvertiserId(bool requestTrackingAuthorization) async {
  try {
    if (kIsWeb)
      throw PlatformException(
          code: "advertiserId not supported on web platform");
    return await AdvertisingId.id(requestTrackingAuthorization);
  } on PlatformException {
    return null;
  }
}
